<?php

namespace SGalinski\SgJobs\Domain\Repository;

/***************************************************************
 *  Copyright notice
 *
 *  (c) sgalinski Internet Services (https://www.sgalinski.de)
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use TYPO3\CMS\Core\Database\DatabaseConnection;
use TYPO3\CMS\Extbase\Persistence\Repository;

/**
 * Company Repository
 */
class CompanyRepository extends Repository {

	const TABLENAME = 'tx_sgjobs_domain_model_company';

	/**
	 * initializes the object
	 */
	public function initializeObject() {
		$querySettings = $this->createQuery()->getQuerySettings();
		$querySettings->setRespectStoragePage(FALSE);
		$querySettings->setIgnoreEnableFields(TRUE);
		$querySettings->setEnableFieldsToBeIgnored(['disabled']);
		$this->setDefaultQuerySettings($querySettings);
	}

	/**
	 * Returns all countries filtered by page id
	 *
	 * @param int $pageUid
	 * @return mixed
	 */
	public function getAllCountries($pageUid) {
		/** @var DatabaseConnection $db */
		$db = $GLOBALS['TYPO3_DB'];
		$result = $db->exec_SELECTquery(
			'country', 'tx_sgjobs_domain_model_company', 'pid = ' . (int) $pageUid, 'country'
		)->fetch_all();

		$countryArray = [''];
		foreach ($result as $country) {
			$countryArray[$country[0]] = $country[0];
		}

		return $countryArray;
	}

	/**
	 * Returns all filtered cities
	 *
	 * @param int $pageUid
	 * @param array $filters
	 * @return mixed
	 */
	public function getAllCities($pageUid, array $filters = []) {
		/** @var DatabaseConnection $db */
		$db = $GLOBALS['TYPO3_DB'];
		$where = 'pid = ' . $db->quoteStr($pageUid, self::TABLENAME);
		if ($filters['country'] && $filters['country'] !== 0) {
			$where .= ' AND country = ' . $db->quoteStr($filters['country'], self::TABLENAME);
		}
		$result = $db->exec_SELECTquery('city', self::TABLENAME, $where, 'city')->fetch_all();

		$cityArray = [''];
		foreach ($result as $city) {
			$cityArray[$city[0]] = $city[0];
		}

		return $cityArray;
	}

	/**
	 * Returns all companies filtered by page id
	 *
	 * @param int $pageUid
	 * @return mixed
	 */
	public function getAllCompanyNames($pageUid) {
		/** @var DatabaseConnection $db */
		$db = $GLOBALS['TYPO3_DB'];
		$result = $db->exec_SELECTquery(
			'name', 'tx_sgjobs_domain_model_company', 'pid = ' . (int) $pageUid, 'name'
		)->fetch_all();

		$namesArray = [''];
		foreach ($result as $name) {
			$namesArray[$name[0]] = $name[0];
		}

		return $namesArray;
	}
}
